import _pt from "prop-types";
import React from "react";
const styles = ".form-input {\n  position: relative; }\n  .form-input-field {\n    width: 100%;\n    border-radius: 0.25rem;\n    background-color: #fff;\n    color: #495057;\n    font-weight: 400;\n    font-size: 0.875rem; }\n    .form-input-field:focus {\n      outline: none;\n      border-color: #ced4da;\n      box-shadow: none; }\n  .form-input-outlined {\n    border: 1px solid #ced4da; }\n  .form-input-filled {\n    border-top: none;\n    border-left: none;\n    border-right: none;\n    border-bottom: 1px solid #ced4da; }\n  .form-input-xs {\n    min-height: 28px; }\n  [data-icon=both] > .form-input-xs {\n    padding-left: 26px;\n    padding-right: 26px; }\n  [data-icon=left] > .form-input-xs {\n    padding-left: 26px; }\n  [data-icon=right] > .form-input-xs {\n    padding-right: 26px; }\n  .form-input-sm {\n    min-height: 40px; }\n  [data-icon=both] > .form-input-sm {\n    padding-left: 38px;\n    padding-right: 38px; }\n  [data-icon=left] > .form-input-sm {\n    padding-left: 38px; }\n  [data-icon=right] > .form-input-sm {\n    padding-right: 38px; }\n  .form-input-md {\n    min-height: 50px; }\n  [data-icon=both] > .form-input-md {\n    padding-left: 48px;\n    padding-right: 48px; }\n  [data-icon=left] > .form-input-md {\n    padding-left: 48px; }\n  [data-icon=right] > .form-input-md {\n    padding-right: 48px; }\n  .form-input-lg {\n    min-height: 58px; }\n  [data-icon=both] > .form-input-lg {\n    padding-left: 56px;\n    padding-right: 56px; }\n  [data-icon=left] > .form-input-lg {\n    padding-left: 56px; }\n  [data-icon=right] > .form-input-lg {\n    padding-right: 56px; }\n  .form-input .form-icon {\n    position: absolute;\n    top: 50%;\n    transform: translateY(-50%);\n    color: #74788d; }\n    .form-input .form-icon > svg {\n      width: 20px;\n      height: auto; }\n  .form-input .form-left-icon {\n    left: 10px; }\n  .form-input .form-right-icon {\n    right: 10px; }\n    .form-input .form-right-icon > svg {\n      width: 20px; }\n";
export default function FormInput(props) {
  const {
    type = "text",
    size = "lg",
    variant = "outlined",
    name,
    value,
    placeholder,
    disabled = false,
    onChange,
    onBlur,
    onFocus,
    innerRef,
    startIcon = null,
    endIcon = null
  } = props;
  const getIconType = startIcon && endIcon ? "both" : startIcon ? "left" : endIcon ? "right" : null;
  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null,
    /*#__PURE__*/
    React.createElement("div", {
      className: styles["form-input"],
      "data-icon": getIconType
    }, startIcon &&
    /*#__PURE__*/
    React.createElement("div", {
      className: [styles["form-icon"], styles["form-left-icon"]].join(" "),
      "data-testid": "sticon"
    }, startIcon),
    /*#__PURE__*/
    React.createElement("input", {
      className: [styles["form-input-field"], styles[`form-input-${variant}`], styles[`form-input-${size}`]].join(" "),
      ref: innerRef,
      type,
      name,
      value,
      placeholder,
      disabled,
      onChange,
      onFocus,
      onBlur
    }), endIcon &&
    /*#__PURE__*/
    React.createElement("div", {
      className: [styles["form-icon"], styles["form-right-icon"]].join(" "),
      "data-testid": "endicon"
    }, endIcon)))
  );
}
FormInput.propTypes = {
  size: _pt.oneOf(["xs", "sm", "md", "lg"]),
  variant: _pt.oneOf(["outlined", "filled"]),
  name: _pt.string,
  value: _pt.any,
  placeholder: _pt.string,
  disabled: _pt.bool,
  onChange: _pt.func,
  onFocus: _pt.func,
  onBlur: _pt.func
};
//# sourceMappingURL=index.js.map