import _pt from "prop-types";
import React, { useState } from "react";
import { ChevronDown } from "react-feather";
const styles = ".form-container {\n  position: relative; }\n  .form-container .form-select {\n    display: flex;\n    flex-direction: row;\n    justify-content: flex-start;\n    align-items: center;\n    cursor: pointer;\n    gap: 8px; }\n    .form-container .form-select--label {\n      color: black;\n      font-weight: 500;\n      font-size: .8125rem;\n      user-select: none; }\n    .form-container .form-select--arrow-down > svg {\n      width: 13px;\n      height: 13px;\n      vertical-align: middle; }\n    .form-container .form-select--options {\n      position: absolute;\n      bottom: 0;\n      left: 0;\n      padding: 0.25rem;\n      width: 100%;\n      z-index: 1;\n      box-shadow: 0 0.25rem 0.75rem rgba(18, 38, 63, 0.08);\n      text-align: left;\n      background-color: #fff;\n      background-clip: padding-box;\n      border: 1px solid #e9e9ef;\n      border-radius: 0.25rem;\n      min-width: 10rem;\n      transform: translate(0px, 100%);\n      transition: all 250ms linear; }\n      .form-container .form-select--options > div {\n        color: #495057;\n        display: flex;\n        align-items: center;\n        padding: 0.35rem 1rem; }\n      .form-container .form-select--options > div svg {\n        width: 16px;\n        height: 16px;\n        vertical-align: middle;\n        margin-right: 0.25rem; }\n      .form-container .form-select--options > div label {\n        display: block;\n        width: 100%;\n        clear: both;\n        font-weight: 400;\n        font-size: 0.8125rem;\n        text-align: inherit;\n        white-space: nowrap;\n        background-color: transparent;\n        border: 0; }\n    .form-container .form-select--show {\n      display: flex;\n      flex-direction: column;\n      gap: 8px;\n      height: auto; }\n    .form-container .form-select--hide {\n      height: 0;\n      overflow: hidden;\n      border: 0;\n      padding: 0; }\n";

function FormSelect(props) {
  const [show, setShow] = useState(false);
  const [selected, setSelected] = useState();
  const {
    selectUniqueID,
    label,
    startIcon,
    options = [],
    getSelectedValue = () => {
      /* */
    },
    showSelectLabel = false,
    disabled = false // size="sm"

  } = props;

  const onClickHandler = event => {
    setShow(!show);
    event.stopPropagation();
    event.preventDefault();
  };

  const onSelectHandler = (event, val) => {
    setSelected(val);
    getSelectedValue(val);
    setShow(false);
    event.stopPropagation();
  };

  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null,
    /*#__PURE__*/
    React.createElement("div", {
      className: [styles["form-container"]].join(" ")
    },
    /*#__PURE__*/
    React.createElement("div", {
      id: selectUniqueID,
      className: [styles["form-select"]].join(" "),
      onClick: onClickHandler
    }, startIcon &&
    /*#__PURE__*/
    React.createElement("div", {
      className: [styles["form-select--start-icon"]].join(" "),
      "data-testid": "sticon"
    }, startIcon),
    /*#__PURE__*/
    React.createElement("div", {
      className: [styles["form-select--label"]].join(" ")
    }, showSelectLabel ? selected?.label : label),
    /*#__PURE__*/
    React.createElement("div", {
      className: styles["form-select--arrow-down"],
      "data-testid": "cheicon"
    },
    /*#__PURE__*/
    React.createElement(ChevronDown, null))),
    /*#__PURE__*/
    React.createElement("div", {
      className: [styles["form-select--options"], styles[`form-select--${show && !disabled ? "show" : "hide"}`]].join(" "),
      "data-testid": "optionsid"
    }, options?.map((option, index) =>
    /*#__PURE__*/
    React.createElement("div", {
      key: index,
      "data-id": option?.id,
      "data-value": option?.value,
      onClick: event => onSelectHandler(event, option),
      "data-testid": "optionid"
    }, (option?.leftIcon),
    /*#__PURE__*/
    React.createElement("label", {
      "data-testid": "label"
    }, (option?.label)), (option?.rightIcon))))))
  );
}

FormSelect.propTypes = {
  selectUniqueID: _pt.string,
  label: _pt.string,
  startIcon: _pt.node,
  options: _pt.arrayOf(_pt.shape({
    id: _pt.oneOfType([_pt.string, _pt.number]),
    label: _pt.string,
    value: _pt.string,
    leftIcon: _pt.node,
    rightIcon: _pt.node
  })),
  getSelectedValue: _pt.func,
  showSelectLabel: _pt.bool,
  disabled: _pt.bool
};
export default FormSelect;
//# sourceMappingURL=index.js.map