"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = FormInput;

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireDefault(require("react"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styles = ".form-input {\n  position: relative; }\n  .form-input-field {\n    width: 100%;\n    border-radius: 0.25rem;\n    background-color: #fff;\n    color: #495057;\n    font-weight: 400;\n    font-size: 0.875rem; }\n    .form-input-field:focus {\n      outline: none;\n      border-color: #ced4da;\n      box-shadow: none; }\n  .form-input-outlined {\n    border: 1px solid #ced4da; }\n  .form-input-filled {\n    border-top: none;\n    border-left: none;\n    border-right: none;\n    border-bottom: 1px solid #ced4da; }\n  .form-input-xs {\n    min-height: 28px; }\n  [data-icon=both] > .form-input-xs {\n    padding-left: 26px;\n    padding-right: 26px; }\n  [data-icon=left] > .form-input-xs {\n    padding-left: 26px; }\n  [data-icon=right] > .form-input-xs {\n    padding-right: 26px; }\n  .form-input-sm {\n    min-height: 40px; }\n  [data-icon=both] > .form-input-sm {\n    padding-left: 38px;\n    padding-right: 38px; }\n  [data-icon=left] > .form-input-sm {\n    padding-left: 38px; }\n  [data-icon=right] > .form-input-sm {\n    padding-right: 38px; }\n  .form-input-md {\n    min-height: 50px; }\n  [data-icon=both] > .form-input-md {\n    padding-left: 48px;\n    padding-right: 48px; }\n  [data-icon=left] > .form-input-md {\n    padding-left: 48px; }\n  [data-icon=right] > .form-input-md {\n    padding-right: 48px; }\n  .form-input-lg {\n    min-height: 58px; }\n  [data-icon=both] > .form-input-lg {\n    padding-left: 56px;\n    padding-right: 56px; }\n  [data-icon=left] > .form-input-lg {\n    padding-left: 56px; }\n  [data-icon=right] > .form-input-lg {\n    padding-right: 56px; }\n  .form-input .form-icon {\n    position: absolute;\n    top: 50%;\n    transform: translateY(-50%);\n    color: #74788d; }\n    .form-input .form-icon > svg {\n      width: 20px;\n      height: auto; }\n  .form-input .form-left-icon {\n    left: 10px; }\n  .form-input .form-right-icon {\n    right: 10px; }\n    .form-input .form-right-icon > svg {\n      width: 20px; }\n";

function FormInput(props) {
  var _props$type = props.type,
      type = _props$type === void 0 ? "text" : _props$type,
      _props$size = props.size,
      size = _props$size === void 0 ? "lg" : _props$size,
      _props$variant = props.variant,
      variant = _props$variant === void 0 ? "outlined" : _props$variant,
      name = props.name,
      value = props.value,
      placeholder = props.placeholder,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      onChange = props.onChange,
      onBlur = props.onBlur,
      onFocus = props.onFocus,
      innerRef = props.innerRef,
      _props$startIcon = props.startIcon,
      startIcon = _props$startIcon === void 0 ? null : _props$startIcon,
      _props$endIcon = props.endIcon,
      endIcon = _props$endIcon === void 0 ? null : _props$endIcon;
  var getIconType = startIcon && endIcon ? "both" : startIcon ? "left" : endIcon ? "right" : null;
  return (
    /*#__PURE__*/
    _react.default.createElement(_react.default.Fragment, null,
    /*#__PURE__*/
    _react.default.createElement("div", {
      className: styles["form-input"],
      "data-icon": getIconType
    }, startIcon &&
    /*#__PURE__*/
    _react.default.createElement("div", {
      className: [styles["form-icon"], styles["form-left-icon"]].join(" "),
      "data-testid": "sticon"
    }, startIcon),
    /*#__PURE__*/
    _react.default.createElement("input", {
      className: [styles["form-input-field"], styles["form-input-".concat(variant)], styles["form-input-".concat(size)]].join(" "),
      ref: innerRef,
      type: type,
      name: name,
      value: value,
      placeholder: placeholder,
      disabled: disabled,
      onChange: onChange,
      onFocus: onFocus,
      onBlur: onBlur
    }), endIcon &&
    /*#__PURE__*/
    _react.default.createElement("div", {
      className: [styles["form-icon"], styles["form-right-icon"]].join(" "),
      "data-testid": "endicon"
    }, endIcon)))
  );
}

FormInput.propTypes = {
  size: _propTypes.default.oneOf(["xs", "sm", "md", "lg"]),
  variant: _propTypes.default.oneOf(["outlined", "filled"]),
  name: _propTypes.default.string,
  value: _propTypes.default.any,
  placeholder: _propTypes.default.string,
  disabled: _propTypes.default.bool,
  onChange: _propTypes.default.func,
  onFocus: _propTypes.default.func,
  onBlur: _propTypes.default.func
};
//# sourceMappingURL=index.js.map