(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "prop-types", "react"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("prop-types"), require("react"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.propTypes, global.react);
    global.undefined = mod.exports;
  }
})(this, function (exports, _propTypes, _react) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = FormInput;

  var _propTypes2 = _interopRequireDefault(_propTypes);

  var _react2 = _interopRequireDefault(_react);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  const styles = ".form-input {\n  position: relative; }\n  .form-input-field {\n    width: 100%;\n    border-radius: 0.25rem;\n    background-color: #fff;\n    color: #495057;\n    font-weight: 400;\n    font-size: 0.875rem; }\n    .form-input-field:focus {\n      outline: none;\n      border-color: #ced4da;\n      box-shadow: none; }\n  .form-input-outlined {\n    border: 1px solid #ced4da; }\n  .form-input-filled {\n    border-top: none;\n    border-left: none;\n    border-right: none;\n    border-bottom: 1px solid #ced4da; }\n  .form-input-xs {\n    min-height: 28px; }\n  [data-icon=both] > .form-input-xs {\n    padding-left: 26px;\n    padding-right: 26px; }\n  [data-icon=left] > .form-input-xs {\n    padding-left: 26px; }\n  [data-icon=right] > .form-input-xs {\n    padding-right: 26px; }\n  .form-input-sm {\n    min-height: 40px; }\n  [data-icon=both] > .form-input-sm {\n    padding-left: 38px;\n    padding-right: 38px; }\n  [data-icon=left] > .form-input-sm {\n    padding-left: 38px; }\n  [data-icon=right] > .form-input-sm {\n    padding-right: 38px; }\n  .form-input-md {\n    min-height: 50px; }\n  [data-icon=both] > .form-input-md {\n    padding-left: 48px;\n    padding-right: 48px; }\n  [data-icon=left] > .form-input-md {\n    padding-left: 48px; }\n  [data-icon=right] > .form-input-md {\n    padding-right: 48px; }\n  .form-input-lg {\n    min-height: 58px; }\n  [data-icon=both] > .form-input-lg {\n    padding-left: 56px;\n    padding-right: 56px; }\n  [data-icon=left] > .form-input-lg {\n    padding-left: 56px; }\n  [data-icon=right] > .form-input-lg {\n    padding-right: 56px; }\n  .form-input .form-icon {\n    position: absolute;\n    top: 50%;\n    transform: translateY(-50%);\n    color: #74788d; }\n    .form-input .form-icon > svg {\n      width: 20px;\n      height: auto; }\n  .form-input .form-left-icon {\n    left: 10px; }\n  .form-input .form-right-icon {\n    right: 10px; }\n    .form-input .form-right-icon > svg {\n      width: 20px; }\n";

  function FormInput(props) {
    const {
      type = "text",
      size = "lg",
      variant = "outlined",
      name,
      value,
      placeholder,
      disabled = false,
      onChange,
      onBlur,
      onFocus,
      innerRef,
      startIcon = null,
      endIcon = null
    } = props;
    const getIconType = startIcon && endIcon ? "both" : startIcon ? "left" : endIcon ? "right" : null;
    return (
      /*#__PURE__*/
      _react2.default.createElement(_react2.default.Fragment, null,
      /*#__PURE__*/
      _react2.default.createElement("div", {
        className: styles["form-input"],
        "data-icon": getIconType
      }, startIcon &&
      /*#__PURE__*/
      _react2.default.createElement("div", {
        className: [styles["form-icon"], styles["form-left-icon"]].join(" "),
        "data-testid": "sticon"
      }, startIcon),
      /*#__PURE__*/
      _react2.default.createElement("input", {
        className: [styles["form-input-field"], styles[`form-input-${variant}`], styles[`form-input-${size}`]].join(" "),
        ref: innerRef,
        type,
        name,
        value,
        placeholder,
        disabled,
        onChange,
        onFocus,
        onBlur
      }), endIcon &&
      /*#__PURE__*/
      _react2.default.createElement("div", {
        className: [styles["form-icon"], styles["form-right-icon"]].join(" "),
        "data-testid": "endicon"
      }, endIcon)))
    );
  }

  FormInput.propTypes = {
    size: _propTypes2.default.oneOf(["xs", "sm", "md", "lg"]),
    variant: _propTypes2.default.oneOf(["outlined", "filled"]),
    name: _propTypes2.default.string,
    value: _propTypes2.default.any,
    placeholder: _propTypes2.default.string,
    disabled: _propTypes2.default.bool,
    onChange: _propTypes2.default.func,
    onFocus: _propTypes2.default.func,
    onBlur: _propTypes2.default.func
  };
});
//# sourceMappingURL=index.js.map