(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "prop-types", "react", "react-feather"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("prop-types"), require("react"), require("react-feather"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.propTypes, global.react, global.reactFeather);
    global.undefined = mod.exports;
  }
})(this, function (exports, _propTypes, _react, _reactFeather) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _propTypes2 = _interopRequireDefault(_propTypes);

  var _react2 = _interopRequireDefault(_react);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  const styles = ".form-container {\n  position: relative; }\n  .form-container .form-select {\n    display: flex;\n    flex-direction: row;\n    justify-content: flex-start;\n    align-items: center;\n    cursor: pointer;\n    gap: 8px; }\n    .form-container .form-select--label {\n      color: black;\n      font-weight: 500;\n      font-size: .8125rem;\n      user-select: none; }\n    .form-container .form-select--arrow-down > svg {\n      width: 13px;\n      height: 13px;\n      vertical-align: middle; }\n    .form-container .form-select--options {\n      position: absolute;\n      bottom: 0;\n      left: 0;\n      padding: 0.25rem;\n      width: 100%;\n      z-index: 1;\n      box-shadow: 0 0.25rem 0.75rem rgba(18, 38, 63, 0.08);\n      text-align: left;\n      background-color: #fff;\n      background-clip: padding-box;\n      border: 1px solid #e9e9ef;\n      border-radius: 0.25rem;\n      min-width: 10rem;\n      transform: translate(0px, 100%);\n      transition: all 250ms linear; }\n      .form-container .form-select--options > div {\n        color: #495057;\n        display: flex;\n        align-items: center;\n        padding: 0.35rem 1rem; }\n      .form-container .form-select--options > div svg {\n        width: 16px;\n        height: 16px;\n        vertical-align: middle;\n        margin-right: 0.25rem; }\n      .form-container .form-select--options > div label {\n        display: block;\n        width: 100%;\n        clear: both;\n        font-weight: 400;\n        font-size: 0.8125rem;\n        text-align: inherit;\n        white-space: nowrap;\n        background-color: transparent;\n        border: 0; }\n    .form-container .form-select--show {\n      display: flex;\n      flex-direction: column;\n      gap: 8px;\n      height: auto; }\n    .form-container .form-select--hide {\n      height: 0;\n      overflow: hidden;\n      border: 0;\n      padding: 0; }\n";

  function FormSelect(props) {
    const [show, setShow] = (0, _react.useState)(false);
    const [selected, setSelected] = (0, _react.useState)();
    const {
      selectUniqueID,
      label,
      startIcon,
      options = [],
      getSelectedValue = () => {
        /* */
      },
      showSelectLabel = false,
      disabled = false // size="sm"

    } = props;

    const onClickHandler = event => {
      setShow(!show);
      event.stopPropagation();
      event.preventDefault();
    };

    const onSelectHandler = (event, val) => {
      setSelected(val);
      getSelectedValue(val);
      setShow(false);
      event.stopPropagation();
    };

    return (
      /*#__PURE__*/
      _react2.default.createElement(_react2.default.Fragment, null,
      /*#__PURE__*/
      _react2.default.createElement("div", {
        className: [styles["form-container"]].join(" ")
      },
      /*#__PURE__*/
      _react2.default.createElement("div", {
        id: selectUniqueID,
        className: [styles["form-select"]].join(" "),
        onClick: onClickHandler
      }, startIcon &&
      /*#__PURE__*/
      _react2.default.createElement("div", {
        className: [styles["form-select--start-icon"]].join(" "),
        "data-testid": "sticon"
      }, startIcon),
      /*#__PURE__*/
      _react2.default.createElement("div", {
        className: [styles["form-select--label"]].join(" ")
      }, showSelectLabel ? selected?.label : label),
      /*#__PURE__*/
      _react2.default.createElement("div", {
        className: styles["form-select--arrow-down"],
        "data-testid": "cheicon"
      },
      /*#__PURE__*/
      _react2.default.createElement(_reactFeather.ChevronDown, null))),
      /*#__PURE__*/
      _react2.default.createElement("div", {
        className: [styles["form-select--options"], styles[`form-select--${show && !disabled ? "show" : "hide"}`]].join(" "),
        "data-testid": "optionsid"
      }, options?.map((option, index) =>
      /*#__PURE__*/
      _react2.default.createElement("div", {
        key: index,
        "data-id": option?.id,
        "data-value": option?.value,
        onClick: event => onSelectHandler(event, option),
        "data-testid": "optionid"
      }, (option?.leftIcon),
      /*#__PURE__*/
      _react2.default.createElement("label", {
        "data-testid": "label"
      }, (option?.label)), (option?.rightIcon))))))
    );
  }

  FormSelect.propTypes = {
    selectUniqueID: _propTypes2.default.string,
    label: _propTypes2.default.string,
    startIcon: _propTypes2.default.node,
    options: _propTypes2.default.arrayOf(_propTypes2.default.shape({
      id: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
      label: _propTypes2.default.string,
      value: _propTypes2.default.string,
      leftIcon: _propTypes2.default.node,
      rightIcon: _propTypes2.default.node
    })),
    getSelectedValue: _propTypes2.default.func,
    showSelectLabel: _propTypes2.default.bool,
    disabled: _propTypes2.default.bool
  };
  exports.default = FormSelect;
});
//# sourceMappingURL=index.js.map