import React from "react";

const variantTypes = {
    filled : "filled",
    outlined : "outlined",
    rounded : "rounded"
}
const sizeTypes = {
    sm : "sm",
    md : "md",
    lg : "lg"
}

interface ButtonProps {
    children ?: React.ReactNode,
    variant ?:  keyof typeof variantTypes,
    size ? : keyof typeof sizeTypes,
    innerRef ?: React.RefObject<HTMLButtonElement>,
    onClick ?: (event: React.MouseEvent<HTMLButtonElement>) => void,
    startIcon ?:  React.ReactSVGElement | React.ReactNode,
    endIcon ?: React.ReactSVGElement | React.ReactNode,
    id?:string
}

export default function FormButton(props : ButtonProps){
    const {
        children,
        size='sm',
        variant = "filled",
        innerRef,
        onClick = () => {/* */},
        startIcon = null,
        endIcon = null
    } = props;
    const onClickHandler = (e : React.MouseEvent<HTMLButtonElement>) => {
        onClick(e);
        e.stopPropagation();
        e.preventDefault();
    }
    return <>
        <button
            {...{
                onClick : onClickHandler,
                ref : innerRef
            }} data-testid={props.id}>
           {startIcon && <span data-testid="sticon">{startIcon}</span>}
            {children}
           {endIcon && <span data-testid="endicon">{endIcon}</span>}
        </button>
    </>
}