import React from "react";
import styles from "./inputfield.module.scss";

interface FormInputProps {
    type ?: React.HTMLInputTypeAttribute,
    size ?: "xs" | "sm" | "md" | "lg",
    variant? : "outlined" | "filled",
    name ?: string,
    value ?: any,
    placeholder ?: string,
    disabled ?: boolean,
    onChange ?: (event : React.ChangeEvent<HTMLInputElement>) => void,
    onFocus ?: (event : React.FocusEvent<HTMLInputElement>) => void,
    onBlur ?: (event : React.FocusEvent<HTMLInputElement>) => void,
    innerRef ?: React.RefObject<HTMLInputElement>,
    startIcon ?:  React.ReactSVGElement | React.ReactNode,
    endIcon ?: React.ReactSVGElement | React.ReactNode,
}

export default function FormInput(props : FormInputProps){
    const {
        type = "text",
        size = "lg",
        variant = "outlined",
        name,
        value,
        placeholder,
        disabled = false,
        onChange,
        onBlur,
        onFocus,
        innerRef,
        startIcon = null,
        endIcon = null
    } = props;

    const getIconType = startIcon && endIcon ? "both" : startIcon ? "left" : endIcon ? "right": null;

    return <>
    <div className={styles["form-input"]} data-icon={getIconType}>
        {startIcon && <div className={[styles["form-icon"], styles["form-left-icon"]].join(" ")} data-testid="sticon">
            {startIcon}
        </div>}
        <input 
            className={[styles["form-input-field"], styles[`form-input-${variant}`], styles[`form-input-${size}`]].join(" ")}
            ref={innerRef}
            {...{
                type,
                name,
                value,
                placeholder,
                disabled,
                onChange,
                onFocus,
                onBlur
            }}/>
        {endIcon && <div className={[styles["form-icon"], styles["form-right-icon"]].join(" ")} data-testid="endicon">
            {endIcon}
        </div>}
    </div>
    </>
}