import React, { memo, useState } from "react";
import { ChevronDown } from "react-feather";
import styles from "./select.module.scss";


type Option = {
    id?: string | number,
    label?: string,
    value?: string,
    leftIcon?: React.ReactNode,
    rightIcon?: React.ReactNode
}
// const sizeTypes = {
//     sm : "sm",
//     md : "md",
//     lg : "lg"
// }
interface SelectProps {
    selectUniqueID?: string,
    label?: string,
    startIcon?: React.ReactNode,
    options?: Array<Option>,
    // selectRef ?: React.RefObject<HTMLSelectElement>,
    getSelectedValue?: (value: Option) => void,
    showSelectLabel?: boolean,
    disabled?: boolean,
    // size?:keyof typeof sizeTypes,
}

function FormSelect(props: SelectProps) {

    const [show, setShow] = useState<boolean>(false);
    const [selected, setSelected] = useState<Option | undefined>();

    const {
        selectUniqueID,
        label,
        startIcon,
        options = [],
        getSelectedValue = () => {/* */},
        showSelectLabel = false,
        disabled = false,
        // size="sm"
    } = props;

    const onClickHandler = (event: React.MouseEvent<HTMLDivElement>) => {
        setShow(!show);
        event.stopPropagation();
        event.preventDefault();
    }

    const onSelectHandler = (event: React.MouseEvent<HTMLDivElement>, val: Option) => {
        setSelected(val);
        getSelectedValue(val);
        setShow(false);
        event.stopPropagation();
    }

    return <>
        <div className={[styles["form-container"]].join(" ")}>
            <div id={selectUniqueID} className={[styles["form-select"]].join(" ")} onClick={onClickHandler}>
                {startIcon && <div className={[styles["form-select--start-icon"]].join(" ")} data-testid="sticon">
                    {startIcon}
                </div>}
                <div className={[styles["form-select--label"]].join(" ")}>{showSelectLabel ? selected?.label : label}</div>
                <div className={styles["form-select--arrow-down"]} data-testid="cheicon">
                    <ChevronDown />
                </div>
            </div>
            <div className={[styles["form-select--options"], styles[`form-select--${(show && !disabled) ? "show" : "hide"}`]].join(" ")} data-testid="optionsid">
                {options?.map((option,index) =>
                    <div key={index} 
                        data-id={option?.id}
                        data-value={option?.value}
                        onClick={(event) => onSelectHandler(event, option)}
                        data-testid="optionid">
                        {option?.leftIcon}
                        <label data-testid="label">{option?.label}</label>
                        {option?.rightIcon}
                    </div>)}
            </div>
        </div>
    </>
}

export default FormSelect;